@@ -9,6 +9,7 @@
 #' @param x a \linkS4class{AcousticEvent} or \linkS4class{AcousticStudy} object
 #' @param value value to assign with accessor
 #' @param i index of the object to access
+#' @param j not used
 #' @param name name of the object to access
 #' @param \dots other arguments to pass to methods
 #'
@@ -229,7 +230,7 @@ setMethod('ancillary<-', 'AcousticEvent', function(x, value) {
 #' @export
 #' @rdname PAMpal.accessors
 #'
-setMethod('[', 'AcousticEvent', function(x, i) {
+setMethod('[', signature(x='AcousticEvent', i='ANY', j='ANY'), function(x, i) {
     x@detectors[i]
 })
 
@@ -261,7 +262,7 @@ setMethod('$<-', 'AcousticEvent', function(x, name, value) {
 #' @export
 #' @rdname PAMpal.accessors
 #'
-setMethod('[[', 'AcousticEvent', function(x, i) {
+setMethod('[[', signature(x='AcousticEvent', i='ANY', j='ANY'), function(x, i, ...) {
     '[['(x@detectors, i)
 })
 
@@ -515,7 +516,7 @@ setMethod('models<-', 'AcousticStudy', function(x, value) {
 #' @export
 #' @rdname PAMpal.accessors
 #'
-setMethod('[', 'AcousticStudy', function(x, i) {
+setMethod('[', signature(x='AcousticStudy', i='ANY', j='ANY'), function(x, i) {
     x@events <- x@events[i]
     x@events <- x@events[sapply(x@events, function(e) {
         !is.null(e)
@@ -551,7 +552,8 @@ setMethod('$<-', 'AcousticStudy', function(x, name, value) {
 #' @export
 #' @rdname PAMpal.accessors
 #'
-setMethod('[[', 'AcousticStudy', function(x, i) {
+setMethod('[[', c('AcousticStudy', 'ANY', 'missing'), function(x, i) {
+# setMethod('[[', 'AcousticStudy', function(x, i, ...) {
     '[['(x@events, i)
 })
 
